import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { CodestarNotificationsServiceException as __BaseException } from "./CodestarNotificationsServiceException";

export declare class AccessDeniedException extends __BaseException {
    readonly name: "AccessDeniedException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<AccessDeniedException, __BaseException>);
}

export declare class ConcurrentModificationException extends __BaseException {
    readonly name: "ConcurrentModificationException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConcurrentModificationException, __BaseException>);
}

export declare class ConfigurationException extends __BaseException {
    readonly name: "ConfigurationException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConfigurationException, __BaseException>);
}
export declare enum DetailType {
    BASIC = "BASIC",
    FULL = "FULL"
}
export declare enum NotificationRuleStatus {
    DISABLED = "DISABLED",
    ENABLED = "ENABLED"
}

export interface Target {
    
    TargetType?: string;
    
    TargetAddress?: string;
}
export declare namespace Target {
    
    const filterSensitiveLog: (obj: Target) => any;
}
export interface CreateNotificationRuleRequest {
    
    Name: string | undefined;
    
    EventTypeIds: string[] | undefined;
    
    Resource: string | undefined;
    
    Targets: Target[] | undefined;
    
    DetailType: DetailType | string | undefined;
    
    ClientRequestToken?: string;
    
    Tags?: {
        [key: string]: string;
    };
    
    Status?: NotificationRuleStatus | string;
}
export declare namespace CreateNotificationRuleRequest {
    
    const filterSensitiveLog: (obj: CreateNotificationRuleRequest) => any;
}
export interface CreateNotificationRuleResult {
    
    Arn?: string;
}
export declare namespace CreateNotificationRuleResult {
    
    const filterSensitiveLog: (obj: CreateNotificationRuleResult) => any;
}

export declare class LimitExceededException extends __BaseException {
    readonly name: "LimitExceededException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<LimitExceededException, __BaseException>);
}

export declare class ResourceAlreadyExistsException extends __BaseException {
    readonly name: "ResourceAlreadyExistsException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ResourceAlreadyExistsException, __BaseException>);
}

export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}
export interface DeleteNotificationRuleRequest {
    
    Arn: string | undefined;
}
export declare namespace DeleteNotificationRuleRequest {
    
    const filterSensitiveLog: (obj: DeleteNotificationRuleRequest) => any;
}
export interface DeleteNotificationRuleResult {
    
    Arn?: string;
}
export declare namespace DeleteNotificationRuleResult {
    
    const filterSensitiveLog: (obj: DeleteNotificationRuleResult) => any;
}
export interface DeleteTargetRequest {
    
    TargetAddress: string | undefined;
    
    ForceUnsubscribeAll?: boolean;
}
export declare namespace DeleteTargetRequest {
    
    const filterSensitiveLog: (obj: DeleteTargetRequest) => any;
}
export interface DeleteTargetResult {
}
export declare namespace DeleteTargetResult {
    
    const filterSensitiveLog: (obj: DeleteTargetResult) => any;
}
export interface DescribeNotificationRuleRequest {
    
    Arn: string | undefined;
}
export declare namespace DescribeNotificationRuleRequest {
    
    const filterSensitiveLog: (obj: DescribeNotificationRuleRequest) => any;
}

export interface EventTypeSummary {
    
    EventTypeId?: string;
    
    ServiceName?: string;
    
    EventTypeName?: string;
    
    ResourceType?: string;
}
export declare namespace EventTypeSummary {
    
    const filterSensitiveLog: (obj: EventTypeSummary) => any;
}
export declare enum TargetStatus {
    ACTIVE = "ACTIVE",
    DEACTIVATED = "DEACTIVATED",
    INACTIVE = "INACTIVE",
    PENDING = "PENDING",
    UNREACHABLE = "UNREACHABLE"
}

export interface TargetSummary {
    
    TargetAddress?: string;
    
    TargetType?: string;
    
    TargetStatus?: TargetStatus | string;
}
export declare namespace TargetSummary {
    
    const filterSensitiveLog: (obj: TargetSummary) => any;
}
export interface DescribeNotificationRuleResult {
    
    Arn: string | undefined;
    
    Name?: string;
    
    EventTypes?: EventTypeSummary[];
    
    Resource?: string;
    
    Targets?: TargetSummary[];
    
    DetailType?: DetailType | string;
    
    CreatedBy?: string;
    
    Status?: NotificationRuleStatus | string;
    
    CreatedTimestamp?: Date;
    
    LastModifiedTimestamp?: Date;
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace DescribeNotificationRuleResult {
    
    const filterSensitiveLog: (obj: DescribeNotificationRuleResult) => any;
}

export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}

export declare class InvalidNextTokenException extends __BaseException {
    readonly name: "InvalidNextTokenException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InvalidNextTokenException, __BaseException>);
}
export declare enum ListEventTypesFilterName {
    RESOURCE_TYPE = "RESOURCE_TYPE",
    SERVICE_NAME = "SERVICE_NAME"
}

export interface ListEventTypesFilter {
    
    Name: ListEventTypesFilterName | string | undefined;
    
    Value: string | undefined;
}
export declare namespace ListEventTypesFilter {
    
    const filterSensitiveLog: (obj: ListEventTypesFilter) => any;
}
export interface ListEventTypesRequest {
    
    Filters?: ListEventTypesFilter[];
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListEventTypesRequest {
    
    const filterSensitiveLog: (obj: ListEventTypesRequest) => any;
}
export interface ListEventTypesResult {
    
    EventTypes?: EventTypeSummary[];
    
    NextToken?: string;
}
export declare namespace ListEventTypesResult {
    
    const filterSensitiveLog: (obj: ListEventTypesResult) => any;
}
export declare enum ListNotificationRulesFilterName {
    CREATED_BY = "CREATED_BY",
    EVENT_TYPE_ID = "EVENT_TYPE_ID",
    RESOURCE = "RESOURCE",
    TARGET_ADDRESS = "TARGET_ADDRESS"
}

export interface ListNotificationRulesFilter {
    
    Name: ListNotificationRulesFilterName | string | undefined;
    
    Value: string | undefined;
}
export declare namespace ListNotificationRulesFilter {
    
    const filterSensitiveLog: (obj: ListNotificationRulesFilter) => any;
}
export interface ListNotificationRulesRequest {
    
    Filters?: ListNotificationRulesFilter[];
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListNotificationRulesRequest {
    
    const filterSensitiveLog: (obj: ListNotificationRulesRequest) => any;
}

export interface NotificationRuleSummary {
    
    Id?: string;
    
    Arn?: string;
}
export declare namespace NotificationRuleSummary {
    
    const filterSensitiveLog: (obj: NotificationRuleSummary) => any;
}
export interface ListNotificationRulesResult {
    
    NextToken?: string;
    
    NotificationRules?: NotificationRuleSummary[];
}
export declare namespace ListNotificationRulesResult {
    
    const filterSensitiveLog: (obj: ListNotificationRulesResult) => any;
}
export interface ListTagsForResourceRequest {
    
    Arn: string | undefined;
}
export declare namespace ListTagsForResourceRequest {
    
    const filterSensitiveLog: (obj: ListTagsForResourceRequest) => any;
}
export interface ListTagsForResourceResult {
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace ListTagsForResourceResult {
    
    const filterSensitiveLog: (obj: ListTagsForResourceResult) => any;
}
export declare enum ListTargetsFilterName {
    TARGET_ADDRESS = "TARGET_ADDRESS",
    TARGET_STATUS = "TARGET_STATUS",
    TARGET_TYPE = "TARGET_TYPE"
}

export interface ListTargetsFilter {
    
    Name: ListTargetsFilterName | string | undefined;
    
    Value: string | undefined;
}
export declare namespace ListTargetsFilter {
    
    const filterSensitiveLog: (obj: ListTargetsFilter) => any;
}
export interface ListTargetsRequest {
    
    Filters?: ListTargetsFilter[];
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListTargetsRequest {
    
    const filterSensitiveLog: (obj: ListTargetsRequest) => any;
}
export interface ListTargetsResult {
    
    Targets?: TargetSummary[];
    
    NextToken?: string;
}
export declare namespace ListTargetsResult {
    
    const filterSensitiveLog: (obj: ListTargetsResult) => any;
}
export interface SubscribeRequest {
    
    Arn: string | undefined;
    
    Target: Target | undefined;
    
    ClientRequestToken?: string;
}
export declare namespace SubscribeRequest {
    
    const filterSensitiveLog: (obj: SubscribeRequest) => any;
}
export interface SubscribeResult {
    
    Arn?: string;
}
export declare namespace SubscribeResult {
    
    const filterSensitiveLog: (obj: SubscribeResult) => any;
}
export interface TagResourceRequest {
    
    Arn: string | undefined;
    
    Tags: {
        [key: string]: string;
    } | undefined;
}
export declare namespace TagResourceRequest {
    
    const filterSensitiveLog: (obj: TagResourceRequest) => any;
}
export interface TagResourceResult {
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace TagResourceResult {
    
    const filterSensitiveLog: (obj: TagResourceResult) => any;
}
export interface UnsubscribeRequest {
    
    Arn: string | undefined;
    
    TargetAddress: string | undefined;
}
export declare namespace UnsubscribeRequest {
    
    const filterSensitiveLog: (obj: UnsubscribeRequest) => any;
}
export interface UnsubscribeResult {
    
    Arn: string | undefined;
}
export declare namespace UnsubscribeResult {
    
    const filterSensitiveLog: (obj: UnsubscribeResult) => any;
}
export interface UntagResourceRequest {
    
    Arn: string | undefined;
    
    TagKeys: string[] | undefined;
}
export declare namespace UntagResourceRequest {
    
    const filterSensitiveLog: (obj: UntagResourceRequest) => any;
}
export interface UntagResourceResult {
}
export declare namespace UntagResourceResult {
    
    const filterSensitiveLog: (obj: UntagResourceResult) => any;
}
export interface UpdateNotificationRuleRequest {
    
    Arn: string | undefined;
    
    Name?: string;
    
    Status?: NotificationRuleStatus | string;
    
    EventTypeIds?: string[];
    
    Targets?: Target[];
    
    DetailType?: DetailType | string;
}
export declare namespace UpdateNotificationRuleRequest {
    
    const filterSensitiveLog: (obj: UpdateNotificationRuleRequest) => any;
}
export interface UpdateNotificationRuleResult {
}
export declare namespace UpdateNotificationRuleResult {
    
    const filterSensitiveLog: (obj: UpdateNotificationRuleResult) => any;
}
